package de.unibi.citec.clf.bonsai.core.configuration;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

/**
 * One actuator configured by the user.
 * 
 * @author jwienke
 */
public class ConfiguredActuator extends ConfiguredCoreObject {

    private String actuatorClassName;
    private String interfaceClassName;

    /**
     * Returns the name of the interface class that the actuator implements.
     * 
     * @return class name
     */
    public String getInterfaceClassName() {
        return interfaceClassName;
    }

    /**
     * Sets the name of the interface class the actuator implements.
     * 
     * @param interfaceClassName
     *            class name
     */
    public void setInterfaceClassName(String interfaceClassName) {
        this.interfaceClassName = interfaceClassName;
    }

    /**
     * Returns the name of the implementing actuator class.
     * 
     * @return class name
     */
    public String getActuatorClassName() {
        return actuatorClassName;
    }

    /**
     * Sets the name of the implementing actuator class.
     * 
     * @param actuatorClassName
     *            class name
     */
    public void setActuatorClassName(String actuatorClassName) {
        this.actuatorClassName = actuatorClassName;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "[" + getClass().getSimpleName() + ": key = " + getKey()
                + ", actuatorClassName = " + actuatorClassName
                + ", interfaceClassName = " + interfaceClassName
                + ", factoryClassName = " + getFactoryClassName()
                + ", option = " + getOptions() + "]";
    }

}
