package de.unibi.citec.clf.bonsai.sensors;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.io.IOException;

import de.unibi.citec.clf.bonsai.core.Sensor;
import de.unibi.airobots.btl.data.person.FaceIdentificationList;

/**
 * An interface for sensors returning face identification results. Moreover
 * learning new persons can be triggered with this interface.
 * 
 * Returning the identification results may be costly so that it can be enabled
 * via {@link #predict()} or disabled with {@link #idle()}.
 * 
 * @author lziegler
 */
public interface FaceIdentificationSensor2 extends
		Sensor<FaceIdentificationList> {

	/**
	 * Triggers the learning process.
	 */
	void trainNow() throws IOException;

	/**
	 * Sets the current id to be saved for captured faces.
	 * 
	 * @param id
	 *            The if of the person to be captured.
	 */
	void setCurrentId(int id) throws IOException;

	/**
	 * Gets the current id to be saved for captured faces.
	 * 
	 * @return The if of the person to be captured.
	 */
	int getCurrentId() throws IOException;

	/**
	 * Starts the capturing of images of the face in front of the camera.
	 * 
	 * @param id
	 *            The id for storing the captured face.
	 */
	void capture(int id) throws IOException;

	/**
	 * Starts the capturing of images of the face in front of the camera.
	 * Increases the id for storing the captured face.
	 */
	void captureNext() throws IOException;

	/**
	 * Starts the capturing of images of the face in front of the camera.
	 * Increases the id for storing the captured face.
	 */
	void captureCurrent() throws IOException;

	/**
	 * Triggers the idle mode. No detection or prediction will be done.
	 */
	void idle() throws IOException;

	/**
	 * Triggers the prediction mode.
	 */
	void predict() throws IOException;

	/**
	 * Triggers the detection mode. Faces will be detected, but will not be
	 * identified.
	 */
	void detect() throws IOException;

}
