package de.unibi.citec.clf.bonsai.xcf.actuators;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.io.IOException;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import net.sf.xcf.MethodNotFoundException;
import net.sf.xcf.RemoteServer;
import net.sf.xcf.UserException;
import net.sf.xcf.transport.XOPData;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;

import de.unibi.citec.clf.bonsai.actuators.EnterArenaAndLocalizeActuator;
import de.unibi.citec.clf.bonsai.actuators.StartStopActuator;
import de.unibi.citec.clf.bonsai.xcf.RemoteServerReconnectable;

/**
 * Start or stop processing of component by calling xcf server methods.
 * 
 * @author lziegler
 */
public class XcfStartStopActuator implements StartStopActuator,
        RemoteServerReconnectable {

    private Logger logger = Logger.getLogger(getClass());

    private String remoteServerName = "";
    private Object remoteServerLock = new Object();
    private RemoteServer remoteServer = null;

    /**
     * Constructor.
     * 
     * @param remoteServerName
     *            name of remote server
     */
    public XcfStartStopActuator(String remoteServerName) {
        this.remoteServerName = remoteServerName;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, ErrorHandlingPolicy> getRemoteServerNames() {
        Map<String, ErrorHandlingPolicy> servers =
                new HashMap<String, ErrorHandlingPolicy>();
        servers.put(remoteServerName, ErrorHandlingPolicy.SELF_HEALING);
        return servers;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void resetRemoteServer(RemoteServer remoteServer) {
        assert remoteServer.getServerName().equals(remoteServerName);
        synchronized (remoteServerLock) {
            this.remoteServer = remoteServer;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void startProcessing() throws IOException {

        try {
            synchronized (remoteServerLock) {

                if (remoteServer == null) {
                    throw new IllegalStateException("No remote server set.");
                }
                Element elem = new Element("foo");
                Document doc = new Document(elem);
                remoteServer.callMethod("start", new XOPData(doc));
            }
        } catch (MethodNotFoundException e) {
            logger.error(e);
            throw new IOException(e);
        } catch (UserException e) {
            logger.error(e);
            throw new IOException(e);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void stopProcessing() throws IOException {
        try {
            synchronized (remoteServerLock) {

                if (remoteServer == null) {
                    throw new IllegalStateException("No remote server set.");
                }
                Element elem = new Element("foo");
                Document doc = new Document(elem);
                remoteServer.callMethod("stop", new XOPData(doc));
            }
        } catch (MethodNotFoundException e) {
            logger.error(e);
            throw new IOException(e);
        } catch (UserException e) {
            logger.error(e);
            throw new IOException(e);
        }
    }
}
