package de.unibi.citec.clf.bonsai.xcf.configuration;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.util.Map;

import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.citec.clf.bonsai.core.Sensor;
import de.unibi.citec.clf.bonsai.xcf.sensors.XcfFaceIdentificationSensor2;
import de.unibi.airobots.btl.data.person.FaceIdentificationList;

/**
 * Configuration for {@link XcfFaceIdentificationSensor2}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@value #OPTION_RESULT_PUBLISHER_NAME} (required): name of the publisher
 * returning the classification results</li>
 * <li>{@value #OPTION_CONTROL_SERVER_NAME} (required): name of the server used
 * to control classification and learning</li>
 * </ul>
 * 
 * @author lziegler
 */
public class ConfiguredXcfFaceIdentificationSensor2 extends
		ConfiguredXcfSensor<FaceIdentificationList> {

	/**
	 * Name of the options defining the publisher that returns classification
	 * results.
	 */
	public static final String OPTION_RESULT_PUBLISHER_NAME = "resultPublisher";

	/**
	 * Name of the option defining the server to control classification and
	 * learning.
	 */
	public static final String OPTION_CONTROL_SERVER_NAME = "controlServer";

	private String resultSubscriberName = "";
	private String controlServerName = "";

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Sensor<FaceIdentificationList> createInstance() {
		return new XcfFaceIdentificationSensor2(resultSubscriberName,
				controlServerName);
	}

	/**
	 * Checks if the sensor that can be produced is suitable for the requested
	 * configuration.
	 * 
	 * @param sensor
	 *            requested configuration
	 * @return <code>true</code> if suitable
	 */
	public static boolean isSuitableFor(SensorToConfigure sensor) {
		return sensor.getSensorClass()
				.equals(XcfFaceIdentificationSensor2.class)
				&& FaceIdentificationList.class.isAssignableFrom(sensor
						.getDataTypeClass());
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getSubscribersToInitialize() {
		return new String[] { resultSubscriberName };
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void parseOptions(Map<String, String> options)
			throws IllegalArgumentException {

		if (!options.containsKey(OPTION_CONTROL_SERVER_NAME)) {
			throw new IllegalArgumentException("Option '"
					+ OPTION_CONTROL_SERVER_NAME + "' missing.");
		}
		if (!options.containsKey(OPTION_RESULT_PUBLISHER_NAME)) {
			throw new IllegalArgumentException("Option '"
					+ OPTION_RESULT_PUBLISHER_NAME + "' missing.");
		}

		resultSubscriberName = options.get(OPTION_RESULT_PUBLISHER_NAME);
		controlServerName = options.get(OPTION_CONTROL_SERVER_NAME);

	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getRemoteServersToInitialize() {
		return new String[] { controlServerName };
	}

}
