package de.unibi.citec.clf.bonsai.xcf.configuration;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.util.Map;

import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.citec.clf.bonsai.core.Sensor;
import de.unibi.citec.clf.bonsai.sensors.data.ObjectPositionList;
import de.unibi.citec.clf.bonsai.xcf.sensors.XcfSceneObjectSensor;

/**
 * Configuration for {@link XcfSceneObjectSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@value #OPTION_MEMORY_NAME} (required): Name of the active memory that
 * contains the scene information</li>
 * </ul>
 * 
 * @author lziegler
 */
public class ConfiguredXcfSceneObjectSensor extends
        ConfiguredXcfSensor<ObjectPositionList> {

    private String memoryName = "";

    /**
     * Name of the user option to specify the active memory for finding person
     * information.
     */
    public static final String OPTION_MEMORY_NAME = "memoryName";

    /**
     * {@inheritDoc}
     */
    @Override
    public void parseOptions(Map<String, String> options)
            throws IllegalArgumentException {

        if (!options.containsKey(OPTION_MEMORY_NAME)) {
            throw new IllegalArgumentException(
                    "Memory name missing with option " + OPTION_MEMORY_NAME);
        }

        memoryName = options.get(OPTION_MEMORY_NAME);

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<ObjectPositionList> createInstance() {
        return new XcfSceneObjectSensor(memoryName);
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass()
                .equals(XcfSceneObjectSensor.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getSubscribersToInitialize() {
        return new String[0];
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getActiveMemoriesToInitialize() {
        return new String[] { memoryName };
    }

}
