package de.unibi.citec.clf.bonsai.xcf.configuration;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.CoreObjectCreationException;
import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.SlotToConfigure;
import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.WorkingMemoryToConfigure;
import de.unibi.citec.clf.bonsai.core.WorkingMemory;
import java.util.Map;
import java.util.Set;

/**
 * Base class for configuration objects that create working memories. For
 * convenience reasons the default implementation of the
 * {@link #parseOptions(Map)} method already parses a required server name.
 *
 * @author lziegler
 */
public abstract class ConfiguredXcfWorkingMemory extends ConfiguredXcfCoreObject {

    /**
     * Option for remote server based classes defining the remote server name.
     */
    public static final String OPTION_MEMORY_NAME = "memoryName";
    /**
     * Name of the server if parsed by {@link #parseOptions(Map)}.
     */
    private String memoryName = "";
    /**
     * Concrete class for the memory requested by the user in the configuration.
     */
    private Class<? extends WorkingMemory> memoryClass = null;

    /**
     * Override this!
     *
     * @param memoryToConfigure requested configuration
     * @return <code>true</code> if this configuration object is suitable for
     * the requested actuator
     */
    public static boolean isSuitableFor(
            WorkingMemoryToConfigure memoryToConfigure) {
        return false;
    }

    /**
     * Create a new specific actuator instance.
     *
     * @return new instance
     * @throws CoreObjectCreationException problem creating the new instance
     */
    public abstract WorkingMemory createInstance()
            throws CoreObjectCreationException;

    /**
     * {@inheritDoc}
     *
     * Default implementation parsing the memory name.
     */
    @Override
    public void parseOptions(Map<String, String> options)
            throws IllegalArgumentException {

        if (!options.containsKey(OPTION_MEMORY_NAME)) {
            throw new IllegalArgumentException(
                    "Memory name missing in arguments for requested type");
        }

        this.memoryName = options.get(OPTION_MEMORY_NAME);

    }

    /**
     * Returns the configured memory name if this class'
     * {@link #parseOptions(Map)} method is used.
     *
     * @return configured memory name
     */
    public String getMemoryName() {
        return memoryName;
    }

    /**
     * Setter for the implementation class requested by the user.
     *
     * @param memoryClass new working memory class
     */
    public void setWorkingMemoryClass(Class<? extends WorkingMemory> memoryClass) {
        this.memoryClass = memoryClass;
    }

    /**
     * Returns the concrete implementation class for the working memory
     * requested in the configuration.
     *
     * @return implementation class for the working memory
     */
    public Class<? extends WorkingMemory> getWorkingMemoryClass() {
        return memoryClass;
    }

    public abstract void configureMemorySlots(Set<SlotToConfigure> slots);
}
