package de.unibi.citec.clf.bonsai.xcf;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import static org.easymock.classextension.EasyMock.createMock;

import java.util.List;
import java.util.Map;

import net.sf.xcf.XcfManager;
import de.unibi.citec.clf.bonsai.xcf.configuration.ConfiguredXcfSensorListable;

/**
 * Mock for XcfFactory.
 * 
 * @author lziegler
 */
public class XcfFactoryMock extends XcfFactory {

	/**
	 * Constructor.
	 */
	public XcfFactoryMock() {
	}

	/**
	 * {@inheritDoc}
	 */
	@SuppressWarnings("rawtypes")
	@Override
	public boolean canCreateSensor(String key,
			Class<? extends List<?>> listType, Class<?> dataType) {

		System.out.println("contains key: "
				+ configuredListSensorsByKey.containsKey(key));
		System.out.println("known list sensors: " + knownListSensors.size());
		for (Class<? extends ConfiguredXcfSensorListable> clazz : knownListSensors) {
			System.out.println(clazz);
		}
		System.out.println("configuredListSensorsByKey: "
				+ configuredListSensorsByKey.size());
		for (String key0 : configuredListSensorsByKey.keySet()) {
			System.out.println(key0 + ": "
					+ configuredListSensorsByKey.get(key0));
		}

		if (!configuredListSensorsByKey.containsKey(key)) {
			return false;
		}

		System.out.println("is assignable: "
				+ dataType.isAssignableFrom(configuredListSensorsByKey.get(key)
						.getDataType()));

		return super.canCreateSensor(key, listType, dataType);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void initialize(Map<String, String> options)
			throws IllegalArgumentException, InitializationException {

		// setup xcf connection
		try {

			xcfManager = createMock(XcfManager.class);

			// subscriber manager
			if (options.containsKey(OPTION_SUBSCRIBER_CHECK_INTERVAL)) {
				subscriberManager = new SubscriberReconnectableManager(
						xcfManager, Long.parseLong(options
								.get(OPTION_SUBSCRIBER_CHECK_INTERVAL)));
			} else {
				subscriberManager = new SubscriberReconnectableManager(
						xcfManager);
			}

			// remote server manager
			if (options.containsKey(OPTION_REMOTE_SERVER_CHECK_INTERVAL)) {
				remoteServerManager = new RemoteServerReconnectableManager(
						xcfManager, Long.parseLong(options
								.get(OPTION_REMOTE_SERVER_CHECK_INTERVAL)));
			} else {
				remoteServerManager = new RemoteServerReconnectableManager(
						xcfManager);
			}

			// errors on initial subscription
			if (options.containsKey(OPTION_ERROR_ON_INITIAL_SUBSCRIPTION)) {
				subscriberManager.setErrorOnXcfTypeInitialization(Boolean
						.parseBoolean(options
								.get(OPTION_ERROR_ON_INITIAL_SUBSCRIPTION)));
			} else {
				subscriberManager
						.setErrorOnXcfTypeInitialization(ReconnectableManager.DEFAULT_ERROR_ON_TYPE_INITIALIZATION);
			}

			// discover sensors and actuators
			discoverSensorsAndActuators();

		} catch (NumberFormatException e) {
			throw new IllegalArgumentException("Error parsing a number.", e);
		}

	}

}
